@@ -149,7 +149,7 @@ color_create_widget (GtkWidget * dlg)
           /* create color list */
           sw = gtk_scrolled_window_new (NULL, NULL);
           gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
-          gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), options.hscroll_policy, options.vscroll_policy);
+          gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), options.data.hscroll_policy, options.data.vscroll_policy);
           gtk_widget_set_size_request (sw, -1, 75);
           gtk_container_add (GTK_CONTAINER (exp), sw);
           gtk_widget_set_vexpand (sw, TRUE);
