@@ -625,7 +625,7 @@ text_create_widget (GtkWidget * dlg)
 
   sw = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), options.hscroll_policy, options.vscroll_policy);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), options.data.hscroll_policy, options.data.vscroll_policy);
   gtk_box_pack_start (GTK_BOX (w), sw, TRUE, TRUE, 0);
 
 #ifdef HAVE_SOURCEVIEW
